/// <reference types="node" />
import { IDApp, DAppParams, UserId, GameInfo } from "./interfaces/index";
import Contract from "web3/eth/contract";
import { EventEmitter } from "events";
import { DAppPlayerInstance } from "./DAppPlayerInstance";
import { DAppDealerInstance } from "./DAppDealerInstance";
interface ReadyInfo {
    deposit: number;
    dapp: {
        slug: string;
        hash: string;
    };
    address: string;
}
interface IGameInfoRoom {
    on: (event: "ready", callback: (info: ReadyInfo) => void) => void;
    connect: ({ userId: string }: {
        userId: any;
    }) => {
        roomAddress: string;
    };
}
export declare class DApp extends EventEmitter implements IDApp, IGameInfoRoom {
    private _params;
    _instancesMap: Map<UserId, DAppDealerInstance>;
    _gameContractInstance: Contract;
    _gameContractAddress: string;
    _gameInfo: GameInfo;
    _beaconInterval: NodeJS.Timer;
    _gameInfoRoom: IGameInfoRoom;
    dappInstance: DAppPlayerInstance;
    _dappInstancePromise: Promise<DAppPlayerInstance | null>;
    _gameInfoRoomAddress: string;
    constructor(params: DAppParams);
    getView(): {
        name: string;
    };
    getInstancesView(): {
        deposit: number;
        playerBalance: number;
        bankrollerBalance: number;
        profit: number;
        playerAddress: string;
    }[];
    eventNames(): string[];
    startClient(): Promise<DAppPlayerInstance>;
    _chooseServer(readyServers: Map<string, ReadyInfo>): Promise<DAppPlayerInstance | null>;
    startServer(): Promise<void>;
    _startSendingBeacon(timeOut: any): Promise<void>;
    onGameFinished(userId: UserId): void;
    connect(params: {
        userId: string;
    }): {
        roomAddress: string;
    };
}
export {};
