"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const dc_ethereum_utils_1 = require("dc-ethereum-utils");
const dc_configs_1 = require("dc-configs");
const GlobalGameLogicStore_1 = require("./GlobalGameLogicStore");
const DApp_1 = require("./DApp");
class DAppFactory {
    constructor(transportProvider, configuration = dc_configs_1.config.default) {
        this._configuration = configuration;
        this._transportProvider = transportProvider;
        const globalStore = global || window;
        globalStore.DCLib = new GlobalGameLogicStore_1.GlobalGameLogicStore();
    }
    async create(params) {
        const { gasPrice: price, gasLimit: limit, web3HttpProviderUrl: httpProviderUrl, contracts, walletName } = this._configuration;
        this.eth = new dc_ethereum_utils_1.Eth({
            walletName,
            httpProviderUrl,
            ERC20ContractInfo: contracts.ERC20,
            gasParams: { price, limit }
        });
        const { name, gameLogicFunction, gameContractAddress, rules, gameEth } = params;
        const { platformId, blockchainNetwork, privateKey } = this._configuration;
        await this.eth.initAccount(privateKey);
        const dappParams = {
            slug: name,
            platformId,
            blockchainNetwork,
            rules,
            roomProvider: this._transportProvider,
            gameLogicFunction,
            gameContractAddress,
            Eth: gameEth || this.eth
        };
        return new DApp_1.DApp(dappParams);
    }
    async startClient(params) {
        const dapp = await this.create(params);
        const dappInstance = await dapp.startClient();
        return dappInstance;
    }
    async startDealer(params) {
        const dapp = await this.create(params);
        const dappInstance = await dapp.startServer();
        return dappInstance;
    }
}
exports.DAppFactory = DAppFactory;
//# sourceMappingURL=DAppFactory.js.map