import { IMessagingProvider } from "dc-messaging";
import { ETHInstance } from "dc-ethereum-utils";
import Contract from "web3/eth/contract";
import { GameInfo } from "./GameInfo";
export declare type UserId = string;
export interface DAppInstanceParams {
    userId: UserId;
    num: number;
    rules: any;
    roomAddress: string;
    gameLogicFunction: () => IGameLogic;
    gameContractInstance: Contract;
    gameContractAddress: string;
    roomProvider: IMessagingProvider;
    onFinish: (userId: UserId) => void;
    gameInfo: GameInfo;
    Eth: ETHInstance;
}
export interface DAppInstanceView {
    deposit: number;
    playerBalance: number;
    bankrollerBalance: number;
    profit: number;
    playerAddress: string;
}
export interface IDAppInstance {
    on(event: string, func: (data: any) => void): any;
    start(): Promise<void> | void;
}
export interface OpenChannelParams {
    channelId: string;
    playerAddress: string;
    bankrollerAddress: string;
    playerDepositWei: string;
    bankrollerDepositWei: string;
    openingBlock: string;
    n: string;
    e: string;
}
export interface ConnectParams {
    playerDeposit: number;
}
export interface GetChannelDataParams extends ConnectParams {
    playerAddress: string;
    channelId: string;
}
export interface GameData {
    randomRanges: number[][];
    custom?: any;
}
export interface PlayParams {
    userBets: number[];
    gameData: GameData;
}
export interface PlayResult {
    profit: number;
    data?: any;
}
export interface IGameLogic {
    play: (userBets: number[], gameData: GameData, randoms: number[]) => PlayResult;
}
export interface State {
    data: {
        _id: string;
        _playerBalance: number;
        _bankrollerBalance: number;
        _totalBet: number;
        _session: number;
    };
    hash: string;
    signs: {};
}
interface PeerBalance {
    bankroller: number;
    player: number;
}
export interface ChannelStateData {
    deposits: PeerBalance;
    balance: PeerBalance;
    profit: PeerBalance;
}
export interface IDAppPlayerInstance extends IDAppInstance {
    connect(connectData: ConnectParams): Promise<any>;
    openChannel(openChannelData: OpenChannelParams, signature: string): Promise<any>;
    getChannelStateData: () => ChannelStateData;
    play(params: PlayParams): Promise<{
        profit: number;
        randoms: number[];
        data?: any;
    }>;
    closeChannel(closeParams: CloseChannelParams, paramsSignature: string): Promise<any>;
    disconnect(): any;
}
export interface CloseChannelParams {
    _id: string;
    _playerBalance: number;
    _bankrollerBalance: number;
    _totalBet: number;
    _session: number;
}
export interface IDAppDealerInstance extends IDAppInstance {
    getOpenChannelData(data: ConnectParams, signature: string): Promise<SignedResponse<OpenChannelParams>>;
    checkOpenChannel(): Promise<any | Error>;
    callPlay(userBets: PlayParams["userBets"], // array of humanreadable format token value 1 = 1 * 10**18
    gameData: {
        seed: string;
        randomRanges: GameData["randomRanges"];
        custom?: GameData["custom"];
    }, session: number, // aka nonce, every call session++ on channelState
    sign: string): Promise<{
        playResult: PlayResult;
        randoms: number[];
        rndSig: string;
        state: State;
    }>;
    confirmState(state: State): boolean;
    consentCloseChannel(stateSignature: string): ConsentResult;
    checkCloseChannel(): Promise<any | Error>;
}
export interface ConsentResult {
    consentSignature: string;
    bankrollerAddress: string;
}
export interface SignedResponse<TResponse> {
    response: TResponse;
    signature: string;
}
export {};
